@@ -25,39 +25,44 @@ class CreateCertificateRequestRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'cas', '2020-04-07', 'CreateCertificateRequest','cas')
 		self.set_method('POST')
-
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_ProductCode(self): # String
+
+	def get_ProductCode(self):
 		return self.get_query_params().get('ProductCode')
 
-	def set_ProductCode(self, ProductCode):  # String
-		self.add_query_param('ProductCode', ProductCode)
-	def get_Username(self): # String
-		return self.get_query_params().get('Username')
+	def set_ProductCode(self,ProductCode):
+		self.add_query_param('ProductCode',ProductCode)
 
-	def set_Username(self, Username):  # String
-		self.add_query_param('Username', Username)
-	def get_Phone(self): # String
-		return self.get_query_params().get('Phone')
-
-	def set_Phone(self, Phone):  # String
-		self.add_query_param('Phone', Phone)
-	def get_Email(self): # String
-		return self.get_query_params().get('Email')
-
-	def set_Email(self, Email):  # String
-		self.add_query_param('Email', Email)
-	def get_Domain(self): # String
-		return self.get_query_params().get('Domain')
-
-	def set_Domain(self, Domain):  # String
-		self.add_query_param('Domain', Domain)
-	def get_ValidateType(self): # String
+	def get_ValidateType(self):
 		return self.get_query_params().get('ValidateType')
 
-	def set_ValidateType(self, ValidateType):  # String
-		self.add_query_param('ValidateType', ValidateType)
+	def set_ValidateType(self,ValidateType):
+		self.add_query_param('ValidateType',ValidateType)
+
+	def get_Email(self):
+		return self.get_query_params().get('Email')
+
+	def set_Email(self,Email):
+		self.add_query_param('Email',Email)
+
+	def get_Phone(self):
+		return self.get_query_params().get('Phone')
+
+	def set_Phone(self,Phone):
+		self.add_query_param('Phone',Phone)
+
+	def get_Domain(self):
+		return self.get_query_params().get('Domain')
+
+	def set_Domain(self,Domain):
+		self.add_query_param('Domain',Domain)
+
+	def get_Username(self):
+		return self.get_query_params().get('Username')
+
+	def set_Username(self,Username):
+		self.add_query_param('Username',Username)
\ No newline at end of file
