@@ -25,14 +25,14 @@ class DescribePackageStateRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'cas', '2020-04-07', 'DescribePackageState','cas')
 		self.set_method('POST')
-
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_ProductCode(self): # String
+
+	def get_ProductCode(self):
 		return self.get_query_params().get('ProductCode')
 
-	def set_ProductCode(self, ProductCode):  # String
-		self.add_query_param('ProductCode', ProductCode)
+	def set_ProductCode(self,ProductCode):
+		self.add_query_param('ProductCode',ProductCode)
\ No newline at end of file
